@@ -27,6 +27,7 @@ extern int expr_eval (void);
 
 extern void expr_print (int);
 extern int  expr_count (int);
-extern int  expr_next (int, int, int *);
+extern int  expr_near (int, int);
+extern int  expr_next (int, int, int, int);
 
 #endif
