@@ -21,18 +21,17 @@
 #ifndef SGML_H
 #define SGML_H
 
-enum element
+enum tag
 {
-  E_NU, /* null           */
-  E_IG, /* ignore         */
-  E_SP, /* space          */
-  E_NL, /* new line       */
-  E_NP, /* new page       */
-  E_LT, /* left tag       */
-  E_NA  /* not applicable */
+  T_NU, /* null           */
+  T_IG, /* ignore         */
+  T_SP, /* space          */
+  T_NL, /* new line       */
+  T_NP, /* new page       */
+  T_NA  /* not applicable */
 };
 
-enum element get_element (char **, char *);
+enum tag get_tag (char **, char *);
 unsigned char get_character (char **, char *);
 
 #endif
